(self.webpackChunkreana_jupyterlab=self.webpackChunkreana_jupyterlab||[]).push([[89],{89:(e,r,t)=>{var n=t(341),o=t(470);e.exports=function e(r){return r?r instanceof Date?r:Array.isArray(r)?r.map((function(r){return e(r)})):"object"==typeof r?o(r,(function(t,o){var a=n(t);if(t!==a&&a in r)throw new Error("Camelcased key `"+a+"` would overwrite existing key of the given JSON object");return[a,e(o)]})):r:r}},341:e=>{"use strict";e.exports=function(){var e=[].map.call(arguments,(function(e){return e.trim()})).filter((function(e){return e.length})).join("-");return e.length?1===e.length?e:/[_.\- ]+/.test(e)?(e=function(e){for(var r=!1,t=0;t<e.length;t++){var n=e.charAt(t);r&&/[a-zA-Z]/.test(n)&&n.toUpperCase()===n?(e=e.substr(0,t)+"-"+e.substr(t),r=!1,t++):r=n.toLowerCase()===n}return e}(e)).replace(/^[_.\- ]+/,"").toLowerCase().replace(/[_.\- ]+(\w|$)/g,(function(e,r){return r.toUpperCase()})):e===e.toUpperCase()?e.toLowerCase():e[0]!==e[0].toLowerCase()?e[0].toLowerCase()+e.slice(1):e:""}},470:e=>{"use strict";e.exports=function(e,r){for(var t={},n=Object.keys(e),o=0;o<n.length;o++){var a=n[o],s=r(a,e[a],e);t[s[0]]=s[1]}return t}}}]);