/* define colors */
:root {
    --sepia: #f5ecec;
    --raven: #667380;
    --platinum: #e8e8e8;
    --light-gray: #cccccc;
    --gray: #767676;
    --dark-gray: #383838;
    --green: #21ba45;
    --blue: #2185d0;
    --red: #db2828;
    --violet: #6435c9;
    --yellow: #fbbd08;
    --teal: #009c95;
    --light-teal: #baeded;
    --isabelline: #f5ecec; 
}

@import url('base.css');

@import url('https://fonts.googleapis.com/icon?family=Material+Symbols+Outlined');