/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/

.my-reanaWidget {
    display: flex;
    flex-direction: column;
    align-items: center;
    overflow: auto;
  }

.jp-Toolbar-micro {
    display: none;
  }

.jp-ReanaExtensionPanel {
    color: var(--jp-ui-font-color1);
    background: var(--jp-layout-color1);
    min-width: var(--jp-sidebar-min-width);
}