import React from 'react'

const logoSvg = `
<svg xmlns="http://www.w3.org/2000/svg" id="tracés_techniques" data-name="tracés techniques" version="1.1" width="100px" viewBox = "0 0 27.5 6.5">
  <defs id="defs5015">
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath27566">
      <path style="opacity:1;fill:#f55;fill-opacity:.4627451;stroke:none;stroke-width:1.20000005;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" id="rect27568" transform="rotate(-45)" d="M1.903 153.297H12.67v4.352H1.903z" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath27602">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01333333;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="m119.05 106.96 5.513-1.472-4.524-3.015-2.937 2.984.066 2.461 2.375 1.43 4.394-1.082.04-1.305z" id="path27604" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath27620">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01333333;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="m119.05 106.96 4.252-1.621-2.208-2.638-2.582.667-1.425 2.557.4 3.209 3.875.565 1.45-1.313.884-1.653z" id="path27622" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath27656">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01333333;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="M123.937 106.833h1.902l-2.35 2.445-4.236-.588.875-5.6 5.375.226-.03 2.95z" id="path27658" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath4807">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01183265;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="m119.05 106.96 4.465-1.764-1.92-1.883-2.58.088-2.143 2.273.078 2.486 3.485 1.082 3.07-1.503-.615-1.446z" id="path4809" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath4823">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01333333;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="m-7.893 9.314.002 5.41 2.02-.728.077-5.937-2.597-1.133z" id="path4825" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath4848">
      <path style="opacity:1;vector-effect:none;fill:none;fill-opacity:1;stroke:#000;stroke-width:.01183265;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" d="m119.05 106.96 4.465-1.764-2.385-2.766-3.079.832-1.03 2.694-.156 2.632 2.38 1.904 2.79-.354 1.363-1.904-.031-1.269z" id="path4850" />
    </clipPath>
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath5015" />
    <clipPath clipPathUnits="userSpaceOnUse" id="clipPath13500" />
  </defs>
  <g id="layer2" transform="translate(-6.952)">
    <path id="path9431" class="jp-icon-3" d="M34.065 2.265v3.849h-1.852v-.68a2.13 2.13 0 0 1-1.807.769 1.83 1.83 0 0 1-2.03-1.852c0-1.116.803-1.774 2.23-1.785h1.552v-.09c0-.58-.38-.925-1.116-.925a4.228 4.228 0 0 0-1.763.49L28.744.793a6.248 6.248 0 0 1 2.733-.67c1.629 0 2.566.804 2.577 2.143zm-1.863 1.852V3.58h-1.194c-.569 0-.848.201-.848.636s.302.703.826.703a1.194 1.194 0 0 0 1.216-.803z" style="fill:currentColor;stroke-width:1.1156683" />
    <path style="fill:currentColor;stroke-width:1.13809323" d="M28.094 2.312v3.801h-1.912V2.847a1.036 1.036 0 0 0-1.07-1.138 1.24 1.24 0 0 0-1.23 1.218v3.186h-1.934V.093h1.935v.979a2.276 2.276 0 0 1 2.014-1.07 2.117 2.117 0 0 1 2.197 2.276z" class="cls-3" id="path9897" />
    <path style="opacity:1;fill:#ff3336;fill-opacity:1;stroke:none;stroke-width:2.25067377;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" id="rect22907" d="M6.952.161h1.633v6H6.952z" />
    <ellipse style="opacity:1;fill:none;fill-opacity:1;stroke:#ff3336;stroke-width:1.1640048;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" id="path27554" cx="117.776" cy="106.194" rx="2.112" ry="2.115" clip-path="url(#clipPath27566)" transform="matrix(1.23637 0 0 1.11567 -135.296 -115.354)" />
    <path style="color:#000;font-style:normal;font-variant:normal;font-weight:400;font-stretch:normal;font-size:medium;line-height:normal;font-family:sans-serif;font-variant-ligatures:normal;font-variant-position:normal;font-variant-caps:normal;font-variant-numeric:normal;font-variant-alternates:normal;font-feature-settings:normal;text-indent:0;text-align:start;text-decoration:none;text-decoration-line:none;text-decoration-style:solid;text-decoration-color:#000;letter-spacing:normal;word-spacing:normal;text-transform:none;writing-mode:lr-tb;direction:ltr;text-orientation:mixed;dominant-baseline:auto;baseline-shift:baseline;text-anchor:start;white-space:normal;shape-padding:0;clip-rule:nonzero;display:inline;overflow:visible;visibility:visible;opacity:1;isolation:auto;mix-blend-mode:normal;color-interpolation:sRGB;color-interpolation-filters:linearRGB;solid-color:#000;solid-opacity:1;vector-effect:none;fill:#ff3336;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1.1640048;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;color-rendering:auto;image-rendering:auto;shape-rendering:auto;text-rendering:auto;enable-background:accumulate" d="M120.367 103.482a2.704 2.704 0 0 0-2.695 2.696 2.706 2.706 0 0 0 2.695 2.697 2.704 2.704 0 0 0 2.694-2.697 2.702 2.702 0 0 0-2.694-2.696zm0 1.164c.852 0 1.53.678 1.53 1.532s-.678 1.533-1.53 1.533c-.851 0-1.531-.68-1.531-1.533 0-.854.68-1.532 1.531-1.532z" clip-path="url(#clipPath4848)" id="ellipse27558" transform="matrix(1.12683 0 0 1.12683 -122.368 -116.497)" />
    <path id="rect27570" style="opacity:1;fill:#ff3336;fill-opacity:1;stroke:none;stroke-width:1.72761714;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" transform="rotate(-111.55 .147 -.02)" clip-path="url(#clipPath4823)" d="M-7.915 8.771h1.254v4.605h-1.254z" />
    <path style="fill:currentColor;stroke-width:1.1156683" d="M21.598 2.263v3.85h-1.852v-.681a2.13 2.13 0 0 1-1.808.77 1.83 1.83 0 0 1-2.03-1.852c0-1.116.803-1.774 2.231-1.785h1.551v-.09c0-.58-.38-.926-1.116-.926a4.228 4.228 0 0 0-1.762.491L16.276.79A6.248 6.248 0 0 1 19.01.122c1.63 0 2.567.804 2.578 2.142zm-1.863 1.852V3.58H18.54c-.57 0-.848.2-.848.636 0 .435.301.703.826.703a1.194 1.194 0 0 0 1.216-.804z" class="cls-3" id="path9863" />
  </g>
</svg>
`;

const ReanaLogo: React.FC = () => (
  <div dangerouslySetInnerHTML={{ __html: logoSvg }} />
);

export default ReanaLogo;